<script setup lang="ts">
import { computed, ref } from 'vue';

import { useVbenDrawer, useVbenModal } from '@vben/common-ui';
import { cloneDeep } from '@vben/utils';

import { InputSearch } from 'ant-design-vue';
import { getMaintSt, updateMaintSt } from '#/api/eims/maint-st';

import { useVbenForm } from '#/adapter/form';
import userModal from '#/views/eims/components/user-modal.vue';

import { drawerSchema } from './data';

const emit = defineEmits<{ reload: [] }>();

const isUpdate = ref(false);
const title = computed(() => {
  return isUpdate.value ? '保养工单汇总稽查' : '保养工单汇总';
});

const [BasicForm, formApi] = useVbenForm({
  commonConfig: {
    formItemClass: 'col-span-2',
    componentProps: {
      class: 'w-full'
    },
    labelWidth: 120
  },
  schema: drawerSchema(),
  showDefaultActions: false,
  wrapperClass: 'grid-cols-2'
});

const [BasicDrawer, drawerApi] = useVbenDrawer({
  onCancel: handleCancel,
  onConfirm: handleConfirm,
  async onOpenChange(isOpen) {
    if (!isOpen) {
      return null;
    }
    drawerApi.drawerLoading(true);
    const { id } = drawerApi.getData() as { id?: number | string };
    isUpdate.value = !!id;
    // 更新 && 赋值
    if (isUpdate.value && id) {
      const record = await getMaintSt(id);
      await formApi.setValues(record);
    }

    drawerApi.drawerLoading(false);
  }
});

async function handleConfirm() {
  try {
    drawerApi.drawerLoading(true);
    const { valid } = await formApi.validate();
    if (!valid) {
      return;
    }
    const data = cloneDeep(await formApi.getValues());
    // await (isUpdate.value ? updateMaintOrderSt(data) : addMaintOrderSt(data));
    await (isUpdate.value ? updateMaintSt(data) : updateMaintSt(data));
    emit('reload');
    await handleCancel();
  } catch (error) {
    console.error(error);
  } finally {
    drawerApi.drawerLoading(false);
  }
}

async function handleCancel() {
  drawerApi.close();
  await formApi.resetForm();
}

// user modal
const [UserModal, userModalApi] = useVbenModal({
  connectedComponent: userModal,
  draggable: true,
  title: '选择稽查人'
});

function handleUserModal() {
  userModalApi.setData({});
  userModalApi.open();
}

/**
 * 更新选择的用户
 * @param user
 */
async function updateUser(user: any) {
  await formApi.setValues({ 'verifyUserName': user.nickName, 'verifyUser': user.userId });
}
</script>

<template>
  <BasicDrawer :close-on-click-modal="false" :title="title" class="w-[600px]">
    <BasicForm>
      <template #verifyUserName="slotProps">
        <InputSearch :enter-button="true" placeholder="请选择" @search="handleUserModal()" v-bind="slotProps" />
      </template>
    </BasicForm>
    <UserModal class="w-[1200px]" @select-user="updateUser" />
  </BasicDrawer>
</template>
